@@ -1,9 +1,10 @@
 import json
 import os
+import re
 import time
 import pytest
 
-from pydrive2.auth import GoogleAuth
+from pydrive2.auth import AuthenticationError, GoogleAuth
 from pydrive2.test.test_util import (
     setup_credentials,
     delete_file,
@@ -188,6 +189,26 @@ def test_12_ServiceAuthFromJsonDictNoCredentialsSaving():
     time.sleep(1)
 
 
+def test_13_LocalWebServerAuthNonInterativeRaises(monkeypatch):
+    settings = {
+        "client_config_backend": "file",
+        "client_config_file": "client_secrets.json",
+        "oauth_scope": ["https://www.googleapis.com/auth/drive"],
+    }
+    ga = GoogleAuth(settings=settings)
+
+    monkeypatch.setenv("GDRIVE_NON_INTERACTIVE", "true")
+    # Test that exception is raised on trying to do browser auth if
+    # we are running in a non interactive environment.
+    with pytest.raises(
+        AuthenticationError,
+        match=re.escape(
+            "Non interactive mode (GDRIVE_NON_INTERACTIVE env) is enabled"
+        ),
+    ):
+        ga.LocalWebserverAuth()
+
+
 def CheckCredentialsFile(credentials, no_file=False):
     ga = GoogleAuth(settings_file_path("test_oauth_default.yaml"))
     ga.LoadCredentialsFile(credentials)
